==> dagger-compiler-2.44-sources.jar: dagger/internal/codegen/binding/AutoValue_DelegateDeclaration.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XTypeElement;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ContributionType;
import dagger.spi.model.DaggerAnnotation;
import dagger.spi.model.DependencyRequest;
import dagger.spi.model.Key;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;

final class AutoValue_DelegateDeclaration extends $AutoValue_DelegateDeclaration {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int hashCode;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean hashCode$Memoized;

  AutoValue_DelegateDeclaration(ContributionType contributionType$, Key key$,
      Optional<XElement> bindingElement$, Optional<XTypeElement> contributingModule$,
      DependencyRequest delegateRequest$, Optional<DaggerAnnotation> mapKey$) {
    super(contributionType$, key$, bindingElement$, contributingModule$, delegateRequest$, mapKey$);
  }

  @Override
  public int hashCode() {
    if (!hashCode$Memoized) {
      synchronized (this) {
        if (!hashCode$Memoized) {
          hashCode = super.hashCode();
          hashCode$Memoized = true;
        }
      }
    }
    return hashCode;
  }

  @Override
  public boolean equals(Object that) {
    if (this == that) {
      return true;
    }
    return that instanceof AutoValue_DelegateDeclaration && this.hashCode() == that.hashCode() && super.equals(that);
  }
}

==> dagger-compiler-2.57-sources.jar: dagger/internal/codegen/binding/AutoValue_DelegateDeclaration.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XTypeElement;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ContributionType;
import dagger.internal.codegen.model.DaggerAnnotation;
import dagger.internal.codegen.model.DependencyRequest;
import dagger.internal.codegen.model.Key;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;

final class AutoValue_DelegateDeclaration extends $AutoValue_DelegateDeclaration {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int hashCode;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean hashCode$Memoized;

  AutoValue_DelegateDeclaration(ContributionType contributionType$, Key key$,
      Optional<XElement> bindingElement$, Optional<XTypeElement> contributingModule$,
      DependencyRequest delegateRequest$, Optional<DaggerAnnotation> mapKey$) {
    super(contributionType$, key$, bindingElement$, contributingModule$, delegateRequest$, mapKey$);
  }

  @Override
  public int hashCode() {
    if (!hashCode$Memoized) {
      synchronized (this) {
        if (!hashCode$Memoized) {
          hashCode = super.hashCode();
          hashCode$Memoized = true;
        }
      }
    }
    return hashCode;
  }

  @Override
  public boolean equals(Object that) {
    if (this == that) {
      return true;
    }
    return that instanceof AutoValue_DelegateDeclaration && this.hashCode() == that.hashCode() && super.equals(that);
  }
}
